@@ -1,5 +1,6 @@
 import argparse
 from datetime import datetime
+import glob
 import io
 import itertools
 import logging
@@ -42,10 +43,21 @@ DESCRIPTION = "{}: v{} (using Python v{})".format(
 )
 VCS = [Git, Mercurial]
 
+# detect either
+# bumpversion:part:value
+# bumpversion:file:value
+# bumpversion:file(suffix):value
+# bumpversion:file ( suffix with spaces):value
+RE_DETECT_SECTION_TYPE = re.compile(
+    r"^bumpversion:"
+    r"((?P<file>file|glob)(\s*\(\s*(?P<file_suffix>[^\):]+)\)?)?|(?P<part>part)):"
+    r"(?P<value>.+)",
+)
 
 logger_list = logging.getLogger("bumpversion.list")
 logger = logging.getLogger(__name__)
 time_context = {"now": datetime.now(), "utcnow": datetime.utcnow()}
+special_char_context = {c: c for c in ("#", ";")}
 
 
 OPTIONAL_ARGUMENTS_THAT_TAKE_VALUES = [
@@ -83,7 +95,12 @@ def main(original_args=None):
     version_config = _setup_versionconfig(known_args, part_configs)
     current_version = version_config.parse(known_args.current_version)
     context = dict(
-        itertools.chain(time_context.items(), prefixed_environ().items(), vcs_info.items())
+        itertools.chain(
+            time_context.items(),
+            prefixed_environ().items(),
+            vcs_info.items(),
+            special_char_context.items(),
+        )
     )
 
     # calculate the desired new version
@@ -93,6 +110,10 @@ def main(original_args=None):
     args, file_names = _parse_arguments_phase_3(remaining_argv, positionals, defaults, parser2)
     new_version = _parse_new_version(args, new_version, version_config)
 
+    # do not use the files from the config
+    if args.no_configured_files:
+        files = []
+
     # replace version in target files
     vcs = _determine_vcs_dirty(VCS, defaults)
     files.extend(
@@ -184,6 +205,10 @@ def _parse_arguments_phase_1(original_args):
 
 def _setup_logging(show_list, verbose):
     logformatter = logging.Formatter("%(message)s")
+    if not logger.handlers:
+        ch1 = logging.StreamHandler(sys.stderr)
+        ch1.setFormatter(logformatter)
+        logger.addHandler(ch1)
     if not logger_list.handlers:
         ch2 = logging.StreamHandler(sys.stdout)
         ch2.setFormatter(logformatter)
@@ -279,18 +304,18 @@ def _load_configuration(config_file, explicit_config, defaults):
 
     part_configs = {}
     files = []
-    file_or_part = re.compile("^bumpversion:(file|part):(.+)")
-    for section_name in config.sections():
-        section_name_match = file_or_part.match(section_name)
 
-        if not section_name_match:
+    for section_name in config.sections():
+        section_type_match = RE_DETECT_SECTION_TYPE.match(section_name)
+
+        if not section_type_match:
             continue
 
-        section_prefix, section_value = section_name_match.groups()
-
+        section_type = section_type_match.groupdict()
+        section_value = section_type.get("value")
         section_config = dict(config.items(section_name))
 
-        if section_prefix == "part":
+        if section_type.get("part"):
             ThisVersionPartConfiguration = NumericVersionPartConfiguration
 
             if "values" in section_config:
@@ -305,8 +330,7 @@ def _load_configuration(config_file, explicit_config, defaults):
             part_configs[section_value] = ThisVersionPartConfiguration(
                 **section_config
             )
-
-        elif section_prefix == "file":
+        elif section_type.get("file"):
             filename = section_value
 
             if "serialize" in section_config:
@@ -340,8 +364,12 @@ def _load_configuration(config_file, explicit_config, defaults):
             if "replace" not in section_config:
                 section_config["replace"] = defaults.get("replace", "{new_version}")
 
-            files.append(ConfiguredFile(filename, VersionConfig(**section_config)))
-
+            version_config = VersionConfig(**section_config)
+            if section_type.get("file") == "glob":
+                for filename_glob in glob.glob(filename, recursive=True):
+                    files.append(ConfiguredFile(filename_glob, version_config))
+            else:
+                files.append(ConfiguredFile(filename, version_config))
     return config, config_file_exists, config_newlines, part_configs, files
 
 
@@ -442,6 +470,13 @@ def _parse_arguments_phase_3(remaining_argv, positionals, defaults, parser2):
         help="Version that needs to be updated",
         required="current_version" not in defaults,
     )
+    parser3.add_argument(
+        "--no-configured-files",
+        action="store_true",
+        default=False,
+        dest="no_configured_files",
+        help="Only replace the version in files specified on the command line, ignoring the files from the configuration file.",
+    )
     parser3.add_argument(
         "--dry-run",
         "-n",
@@ -657,6 +692,7 @@ def _commit_to_vcs(files, context, config_file, config_file_exists, vcs, args,
     context.update(prefixed_environ())
     context.update({'current_' + part: current_version[part].value for part in current_version})
     context.update({'new_' + part: new_version[part].value for part in new_version})
+    context.update(special_char_context)
 
     commit_message = args.message.format(**context)
 
