@@ -15,7 +15,7 @@ import pytest
 from testfixtures import LogCapture
 
 import bumpversion
-from bumpversion.exceptions import WorkingDirectoryIsDirtyException
+from bumpversion import exceptions
 from bumpversion.cli import DESCRIPTION, main, split_args_in_optional_and_positional
 
 
@@ -64,6 +64,17 @@ def configfile(request):
     return request.param
 
 
+@pytest.fixture(params=[
+    "file",
+    "file(suffix)",
+    "file (suffix with space)",
+    "file (suffix lacking closing paren",
+])
+def file_keyword(request):
+    """Return multiple possible styles for the bumpversion:file keyword."""
+    return request.param
+
+
 try:
     RawConfigParser(empty_lines_in_values=False)
     using_old_configparser = False
@@ -95,6 +106,7 @@ EXPECTED_OPTIONS = r"""
 [--search SEARCH]
 [--replace REPLACE]
 [--current-version VERSION]
+[--no-configured-files]
 [--dry-run]
 --new-version VERSION
 [--commit | --no-commit]
@@ -133,6 +145,10 @@ optional arguments:
                         {new_version})
   --current-version VERSION
                         Version that needs to be updated (default: None)
+  --no-configured-files
+                        Only replace the version in files specified on the
+                        command line, ignoring the files from the
+                        configuration file. (default: False)
   --dry-run, -n         Don't write any files, just pretend. (default: False)
   --new-version VERSION
                         New version that should be in the files (default:
@@ -169,7 +185,7 @@ def test_usage_string(tmpdir, capsys):
     assert EXPECTED_USAGE in out
 
 
-def test_usage_string_fork(tmpdir, capsys):
+def test_usage_string_fork(tmpdir):
     tmpdir.chdir()
 
     if platform.system() == "Windows":
@@ -281,6 +297,52 @@ new_version: 0.10.3
     assert "0.10.3" == tmpdir.join("file2").read()
 
 
+def test_glob_keyword(tmpdir, configfile):
+    tmpdir.join("file1.txt").write("0.9.34")
+    tmpdir.join("file2.txt").write("0.9.34")
+    tmpdir.join(configfile).write("""[bumpversion]
+current_version: 0.9.34
+new_version: 0.9.35
+[bumpversion:glob:*.txt]""")
+
+    tmpdir.chdir()
+    main(["patch"])
+    assert "0.9.35" == tmpdir.join("file1.txt").read()
+    assert "0.9.35" == tmpdir.join("file2.txt").read()
+
+def test_glob_keyword_recursive(tmpdir, configfile):
+    tmpdir.mkdir("subdir").mkdir("subdir2")
+    file1 = tmpdir.join("subdir").join("file1.txt")
+    file1.write("0.9.34")
+    file2 = tmpdir.join("subdir").join("subdir2").join("file2.txt")
+    file2.write("0.9.34")
+    tmpdir.join(configfile).write("""[bumpversion]
+current_version: 0.9.34
+new_version: 0.9.35
+[bumpversion:glob:**/*.txt]""")
+
+    tmpdir.chdir()
+    main(["patch"])
+    assert "0.9.35" == file1.read()
+    assert "0.9.35" == file2.read()
+
+
+def test_file_keyword_with_suffix_is_accepted(tmpdir, configfile, file_keyword):
+    tmpdir.join("file2").write("0.10.2")
+    tmpdir.join(configfile).write(
+        """[bumpversion]
+    current_version: 0.10.2
+    new_version: 0.10.3
+    [bumpversion:%s:file2]
+    """ % file_keyword
+    )
+
+    tmpdir.chdir()
+    main(['patch'])
+
+    assert "0.10.3" == tmpdir.join("file2").read()
+
+
 def test_multiple_config_files(tmpdir):
     tmpdir.join("file2").write("0.10.2")
     tmpdir.join("setup.cfg").write("""[bumpversion]
@@ -298,6 +360,39 @@ new_version: 0.10.4
     assert "0.10.4" == tmpdir.join("file2").read()
 
 
+def test_single_file_processed_twice(tmpdir):
+    """
+    Verify that a single file "file2" can be processed twice.
+
+    Use two file_ entries, both with a different suffix after
+    the underscore.
+    Employ different parse/serialize and search/replace configs
+    to verify correct interpretation.
+    """
+    tmpdir.join("file2").write("dots: 0.10.2\ndashes: 0-10-2")
+    tmpdir.join("setup.cfg").write("""[bumpversion]
+current_version: 0.10.2
+new_version: 0.10.3
+[bumpversion:file:file2]""")
+    tmpdir.join(".bumpversion.cfg").write(r"""[bumpversion]
+current_version: 0.10.2
+new_version: 0.10.4
+[bumpversion:file (version with dots):file2]
+search = dots: {current_version}
+replace = dots: {new_version}
+[bumpversion:file (version with dashes):file2]
+search = dashes: {current_version}
+replace = dashes: {new_version}
+parse = (?P<major>\d+)-(?P<minor>\d+)-(?P<patch>\d+)
+serialize = {major}-{minor}-{patch}
+""")
+
+    tmpdir.chdir()
+    main(['patch'])
+
+    assert "dots: 0.10.4\ndashes: 0-10-4" == tmpdir.join("file2").read()
+
+
 def test_config_file_is_updated(tmpdir):
     tmpdir.join("file3").write("0.0.13")
     tmpdir.join(".bumpversion.cfg").write("""[bumpversion]
@@ -347,6 +442,80 @@ message = DO NOT BUMP VERSIONS WITH THIS FILE
     assert "DO NOT" not in vcs_log
 
 
+def test_dry_run_verbose_log(tmpdir, vcs):
+    tmpdir.chdir()
+
+    version = "0.12.0"
+    patch = "0.12.1"
+    v_parts = version.split('.')
+    p_parts = patch.split('.')
+    file = "file4"
+    message = "DO NOT BUMP VERSIONS WITH THIS FILE"
+    config = """[bumpversion]
+current_version = {version}
+tag = True
+commit = True
+message = {message}
+
+[bumpversion:file:{file}]
+
+""".format(version=version, file=file, message=message)
+
+    bumpcfg = ".bumpversion.cfg"
+    tmpdir.join(file).write(version)
+    tmpdir.join(bumpcfg).write(config)
+
+    check_call([vcs, "init"])
+    check_call([vcs, "add", file])
+    check_call([vcs, "add", bumpcfg])
+    check_call([vcs, "commit", "-m", "initial commit"])
+
+    with LogCapture(level=logging.INFO) as log_capture:
+        main(['patch', '--dry-run', '--verbose'])
+
+    vcs_name = "Mercurial" if vcs == "hg" else "Git"
+    log_capture.check_present(
+        # generic --verbose entries
+        ('bumpversion.cli', 'INFO', 'Reading config file {}:'.format(bumpcfg)),
+        ('bumpversion.cli', 'INFO', config),
+        ('bumpversion.version_part', 'INFO',
+         "Parsing version '{}' using regexp '(?P<major>\\d+)\\.(?P<minor>\\d+)\\.(?P<patch>\\d+)'".format(version)),
+        ('bumpversion.version_part', 'INFO',
+         'Parsed the following values: major={}, minor={}, patch={}'.format(v_parts[0], v_parts[1], v_parts[2])),
+        ('bumpversion.cli', 'INFO', "Attempting to increment part 'patch'"),
+        ('bumpversion.cli', 'INFO',
+         'Values are now: major={}, minor={}, patch={}'.format(p_parts[0], p_parts[1], p_parts[2])),
+        ('bumpversion.cli', 'INFO', "Dry run active, won't touch any files."),  # only in dry-run mode
+        ('bumpversion.version_part', 'INFO',
+         "Parsing version '{}' using regexp '(?P<major>\\d+)\\.(?P<minor>\\d+)\\.(?P<patch>\\d+)'".format(patch)),
+        ('bumpversion.version_part', 'INFO',
+         'Parsed the following values: major={}, minor={}, patch={}'.format(p_parts[0], p_parts[1], p_parts[2])),
+        ('bumpversion.cli', 'INFO', "New version will be '{}'".format(patch)),
+        ('bumpversion.cli', 'INFO', 'Asserting files {} contain the version string...'.format(file)),
+        ('bumpversion.utils', 'INFO', "Found '{v}' in {f} at line 0: {v}".format(v=version, f=file)),  # verbose
+        ('bumpversion.utils', 'INFO', 'Would change file {}:'.format(file)),  # dry-run change to 'would'
+        ('bumpversion.utils', 'INFO',
+         '--- a/{f}\n+++ b/{f}\n@@ -1 +1 @@\n-{v}\n+{p}'.format(f=file, v=version, p=patch)),
+        ('bumpversion.list', 'INFO', 'current_version={}'.format(version)),
+        ('bumpversion.list', 'INFO', 'tag=True'),
+        ('bumpversion.list', 'INFO', 'commit=True'),
+        ('bumpversion.list', 'INFO', 'message={}'.format(message)),
+        ('bumpversion.list', 'INFO', 'new_version={}'.format(patch)),
+        ('bumpversion.cli', 'INFO', 'Would write to config file {}:'.format(bumpcfg)),  # dry-run 'would'
+        ('bumpversion.cli', 'INFO', config.replace(version, patch)),
+        # following entries are only present if both --verbose and --dry-run are specified
+        # all entries use 'would do x' variants instead of 'doing x'
+        ('bumpversion.cli', 'INFO', 'Would prepare {vcs} commit'.format(vcs=vcs_name)),
+        ('bumpversion.cli', 'INFO', "Would add changes in file '{file}' to {vcs}".format(file=file, vcs=vcs_name)),
+        ('bumpversion.cli', 'INFO', "Would add changes in file '{file}' to {vcs}".format(file=bumpcfg, vcs=vcs_name)),
+        ('bumpversion.cli', 'INFO', "Would commit to {vcs} with message '{msg}'".format(msg=message, vcs=vcs_name)),
+        ('bumpversion.cli', 'INFO',
+         "Would tag 'v{p}' with message 'Bump version: {v} → {p}' in {vcs} and not signing"
+         .format(v=version, p=patch, vcs=vcs_name)),
+        order_matters=True
+    )
+
+
 def test_bump_version(tmpdir):
     tmpdir.join("file5").write("1.0.0")
     tmpdir.chdir()
@@ -408,7 +577,7 @@ def test_dirty_work_dir(tmpdir, vcs):
     vcs_name = "Mercurial" if vcs == "hg" else "Git"
     vcs_output = "A dirty" if vcs == "hg" else "A  dirty"
 
-    with pytest.raises(WorkingDirectoryIsDirtyException):
+    with pytest.raises(exceptions.WorkingDirectoryIsDirtyException):
         with LogCapture() as log_capture:
             main(['patch', '--current-version', '1', '--new-version', '2', 'file7'])
 
@@ -746,7 +915,7 @@ def test_tag_name(tmpdir, vcs):
     assert b'ReleasedVersion-31.1.2' in tag_out
 
 
-def test_message_from_config_file(tmpdir, capsys, vcs):
+def test_message_from_config_file(tmpdir, vcs):
     tmpdir.chdir()
     check_call([vcs, "init"])
     tmpdir.join("VERSION").write("400.0.0")
@@ -772,7 +941,7 @@ tag_name: from-{current_version}-to-{new_version}""")
     assert b'from-400.0.0-to-401.0.0' in tag_out
 
 
-def test_all_parts_in_message_and_serialize_and_tag_name_from_config_file(tmpdir, capsys, vcs):
+def test_all_parts_in_message_and_serialize_and_tag_name_from_config_file(tmpdir, vcs):
     """
     Ensure that major/minor/patch *and* custom parts can be used everywhere.
 
@@ -811,7 +980,7 @@ tag_name: from-{current_version}-aka-{current_major}.{current_minor}.{current_pa
     assert b'from-400.1.2.101-aka-400.1.2-custom-101-to-401.2.3.102-aka-401.2.3-custom-102' in tag_out
 
 
-def test_all_parts_in_replace_from_config_file(tmpdir, capsys, vcs):
+def test_all_parts_in_replace_from_config_file(tmpdir, vcs):
     """
     Ensure that major/minor/patch *and* custom parts can be used in 'replace'.
     """
@@ -931,7 +1100,7 @@ except ImportError:
 
 @pytest.mark.xfail(not config_parser_handles_utf8,
                    reason="old ConfigParser uses non-utf-8-strings internally")
-def test_utf8_message_from_config_file(tmpdir, capsys, vcs):
+def test_utf8_message_from_config_file(tmpdir, vcs):
     tmpdir.chdir()
     check_call([vcs, "init"])
     tmpdir.join("VERSION").write("500.0.0")
@@ -952,7 +1121,7 @@ message = Nová verze: {current_version} ☃, {new_version} ☀
     assert expected_new_config.encode('utf-8') == tmpdir.join(".bumpversion.cfg").read(mode='rb')
 
 
-def test_utf8_message_from_config_file(tmpdir, capsys, vcs):
+def test_utf8_message_from_config_file(tmpdir, vcs):
     tmpdir.chdir()
     check_call([vcs, "init"])
     tmpdir.join("VERSION").write("10.10.0")
@@ -1082,7 +1251,7 @@ parse = (?P<major>\d+)\.(?P<minor>\d+)(\.(?P<patch>\d+))?
     assert '0.6.1' == tmpdir.join("fileD").read()
 
 
-def test_log_no_config_file_info_message(tmpdir, capsys):
+def test_log_no_config_file_info_message(tmpdir):
     tmpdir.chdir()
 
     tmpdir.join("a_file.txt").write("1.0.0")
@@ -1140,7 +1309,7 @@ def test_log_invalid_regex_exit(tmpdir):
     )
 
 
-def test_complex_info_logging(tmpdir, capsys):
+def test_complex_info_logging(tmpdir):
     tmpdir.join("fileE").write("0.4")
     tmpdir.chdir()
 
@@ -1337,7 +1506,7 @@ def test_no_list_no_stdout(tmpdir, vcs):
     assert out == ""
 
 
-def test_bump_non_numeric_parts(tmpdir, capsys):
+def test_bump_non_numeric_parts(tmpdir):
     tmpdir.join("with_pre_releases.txt").write("1.5.dev")
     tmpdir.chdir()
 
@@ -1397,7 +1566,7 @@ def test_optional_value_from_documentation(tmpdir):
     assert '1' == tmpdir.join("optional_value_from_doc.txt").read()
 
 
-def test_python_pre_release_release_post_release(tmpdir, capsys):
+def test_python_pre_release_release_post_release(tmpdir):
     tmpdir.join("python386.txt").write("1.0a")
     tmpdir.chdir()
 
@@ -1479,7 +1648,7 @@ def test_part_first_value(tmpdir):
     assert '1.1.0' == tmpdir.join("the_version.txt").read()
 
 
-def test_multi_file_configuration(tmpdir, capsys):
+def test_multi_file_configuration(tmpdir):
     tmpdir.join("FULL_VERSION.txt").write("1.0.3")
     tmpdir.join("MAJOR_VERSION.txt").write("1")
 
@@ -1506,7 +1675,7 @@ def test_multi_file_configuration(tmpdir, capsys):
     assert '2' in tmpdir.join("MAJOR_VERSION.txt").read()
 
 
-def test_multi_file_configuration2(tmpdir, capsys):
+def test_multi_file_configuration2(tmpdir):
     tmpdir.join("setup.cfg").write("1.6.6")
     tmpdir.join("README.txt").write("MyAwesomeSoftware(TM) v1.6")
     tmpdir.join("BUILD_NUMBER").write("1.6.6+joe+38943")
@@ -1555,10 +1724,22 @@ def test_multi_file_configuration2(tmpdir, capsys):
     assert '1.7.1+bob+38945' in tmpdir.join("BUILD_NUMBER").read()
 
 
-def test_search_replace_to_avoid_updating_unconcerned_lines(tmpdir, capsys):
+def test_search_replace_to_avoid_updating_unconcerned_lines(tmpdir):
     tmpdir.chdir()
 
     tmpdir.join("requirements.txt").write("Django>=1.5.6,<1.6\nMyProject==1.5.6")
+    tmpdir.join("CHANGELOG.md").write(dedent("""
+    # https://keepachangelog.com/en/1.0.0/
+
+    ## [Unreleased]
+    ### Added
+    - Foobar
+
+    ## [0.0.1] - 2014-05-31
+    ### Added
+    - This CHANGELOG file to hopefully serve as an evolving example of a
+      standardized open source project CHANGELOG.
+    """))
 
     tmpdir.join(".bumpversion.cfg").write(dedent("""
       [bumpversion]
@@ -1567,14 +1748,22 @@ def test_search_replace_to_avoid_updating_unconcerned_lines(tmpdir, capsys):
       [bumpversion:file:requirements.txt]
       search = MyProject=={current_version}
       replace = MyProject=={new_version}
+
+      [bumpversion:file:CHANGELOG.md]
+      search = {#}{#} [Unreleased]
+      replace = {#}{#} [Unreleased]
+
+        {#}{#} [{new_version}] - {utcnow:%Y-%m-%d}
       """).strip())
 
     with LogCapture() as log_capture:
         main(['minor', '--verbose'])
 
+    utc_today = datetime.utcnow().strftime("%Y-%m-%d")
+
     log_capture.check(
         ('bumpversion.cli', 'INFO', 'Reading config file .bumpversion.cfg:'),
-        ('bumpversion.cli', 'INFO', '[bumpversion]\ncurrent_version = 1.5.6\n\n[bumpversion:file:requirements.txt]\nsearch = MyProject=={current_version}\nreplace = MyProject=={new_version}'),
+        ('bumpversion.cli', 'INFO', '[bumpversion]\ncurrent_version = 1.5.6\n\n[bumpversion:file:requirements.txt]\nsearch = MyProject=={current_version}\nreplace = MyProject=={new_version}\n\n[bumpversion:file:CHANGELOG.md]\nsearch = {#}{#} [Unreleased]\nreplace = {#}{#} [Unreleased]\n\n  {#}{#} [{new_version}] - {utcnow:%Y-%m-%d}'),
         ('bumpversion.version_part', 'INFO', "Parsing version '1.5.6' using regexp '(?P<major>\\d+)\\.(?P<minor>\\d+)\\.(?P<patch>\\d+)'"),
         ('bumpversion.version_part', 'INFO', 'Parsed the following values: major=1, minor=5, patch=6'),
         ('bumpversion.cli', 'INFO', "Attempting to increment part 'minor'"),
@@ -1582,21 +1771,24 @@ def test_search_replace_to_avoid_updating_unconcerned_lines(tmpdir, capsys):
         ('bumpversion.version_part', 'INFO', "Parsing version '1.6.0' using regexp '(?P<major>\\d+)\\.(?P<minor>\\d+)\\.(?P<patch>\\d+)'"),
         ('bumpversion.version_part', 'INFO', 'Parsed the following values: major=1, minor=6, patch=0'),
         ('bumpversion.cli', 'INFO', "New version will be '1.6.0'"),
-        ('bumpversion.cli', 'INFO', 'Asserting files requirements.txt contain the version string...'),
+        ('bumpversion.cli', 'INFO', 'Asserting files requirements.txt, CHANGELOG.md contain the version string...'),
         ('bumpversion.utils', 'INFO', "Found 'MyProject==1.5.6' in requirements.txt at line 1: MyProject==1.5.6"),
+        ('bumpversion.utils', 'INFO', "Found '## [Unreleased]' in CHANGELOG.md at line 3: ## [Unreleased]"),
         ('bumpversion.utils', 'INFO', 'Changing file requirements.txt:'),
         ('bumpversion.utils', 'INFO', '--- a/requirements.txt\n+++ b/requirements.txt\n@@ -1,2 +1,2 @@\n Django>=1.5.6,<1.6\n-MyProject==1.5.6\n+MyProject==1.6.0'),
+        ('bumpversion.utils', 'INFO', 'Changing file CHANGELOG.md:'),
+        ('bumpversion.utils', 'INFO', '--- a/CHANGELOG.md\n+++ b/CHANGELOG.md\n@@ -2,6 +2,8 @@\n # https://keepachangelog.com/en/1.0.0/\n \n ## [Unreleased]\n+\n+## [1.6.0] - %s\n ### Added\n - Foobar\n ' % utc_today),
         ('bumpversion.list', 'INFO', 'current_version=1.5.6'),
         ('bumpversion.list', 'INFO', 'new_version=1.6.0'),
         ('bumpversion.cli', 'INFO', 'Writing to config file .bumpversion.cfg:'),
-        ('bumpversion.cli', 'INFO', '[bumpversion]\ncurrent_version = 1.6.0\n\n[bumpversion:file:requirements.txt]\nsearch = MyProject=={current_version}\nreplace = MyProject=={new_version}\n\n')
-    )
+        ('bumpversion.cli', 'INFO', '[bumpversion]\ncurrent_version = 1.6.0\n\n[bumpversion:file:requirements.txt]\nsearch = MyProject=={current_version}\nreplace = MyProject=={new_version}\n\n[bumpversion:file:CHANGELOG.md]\nsearch = {#}{#} [Unreleased]\nreplace = {#}{#} [Unreleased]\n\t\n\t{#}{#} [{new_version}] - {utcnow:%Y-%m-%d}\n\n')
+     )
 
     assert 'MyProject==1.6.0' in tmpdir.join("requirements.txt").read()
     assert 'Django>=1.5.6' in tmpdir.join("requirements.txt").read()
 
 
-def test_search_replace_expanding_changelog(tmpdir, capsys):
+def test_search_replace_expanding_changelog(tmpdir):
     tmpdir.chdir()
 
     tmpdir.join("CHANGELOG.md").write(dedent("""
@@ -1654,7 +1846,42 @@ def test_search_replace_expanding_changelog(tmpdir, capsys):
     assert postdate in tmpdir.join("CHANGELOG.md").read()
 
 
-def test_search_replace_cli(tmpdir, capsys):
+def test_non_matching_search_does_not_modify_file(tmpdir):
+    tmpdir.chdir()
+
+    changelog_content = dedent("""
+    # Unreleased
+    
+    * bullet point A
+    
+    # Release v'older' (2019-09-17)
+    
+    * bullet point B
+    """)
+
+    config_content = dedent("""
+      [bumpversion]
+      current_version = 1.0.3
+
+      [bumpversion:file:CHANGELOG.md]
+      search = Not-yet-released
+      replace = Release v{new_version} ({now:%Y-%m-%d})
+    """)
+
+    tmpdir.join("CHANGELOG.md").write(changelog_content)
+    tmpdir.join(".bumpversion.cfg").write(config_content)
+
+    with pytest.raises(
+            exceptions.VersionNotFoundException,
+            match="Did not find 'Not-yet-released' in file: 'CHANGELOG.md'"
+    ):
+        main(['patch', '--verbose'])
+
+    assert changelog_content == tmpdir.join("CHANGELOG.md").read()
+    assert config_content in tmpdir.join(".bumpversion.cfg").read()
+
+
+def test_search_replace_cli(tmpdir):
     tmpdir.join("file89").write("My birthday: 3.5.98\nCurrent version: 3.5.98")
     tmpdir.chdir()
     main([
@@ -1829,7 +2056,7 @@ def test_configparser_empty_lines_in_values(tmpdir):
     """) == tmpdir.join("CHANGES.rst").read()
 
 
-def test_regression_tag_name_with_hyphens(tmpdir, capsys, git):
+def test_regression_tag_name_with_hyphens(tmpdir, git):
     tmpdir.chdir()
     tmpdir.join("some_source.txt").write("2014.10.22")
     check_call([git, "init"])
@@ -1873,7 +2100,7 @@ message = XXX
     assert "Failed to run" in caplog.text
 
 
-def test_regression_characters_after_last_label_serialize_string(tmpdir, capsys):
+def test_regression_characters_after_last_label_serialize_string(tmpdir):
     tmpdir.chdir()
     tmpdir.join("bower.json").write('''
     {
@@ -1894,7 +2121,7 @@ def test_regression_characters_after_last_label_serialize_string(tmpdir, capsys)
     main(['patch', 'bower.json'])
 
 
-def test_regression_dont_touch_capitalization_of_keys_in_config(tmpdir, capsys):
+def test_regression_dont_touch_capitalization_of_keys_in_config(tmpdir):
     tmpdir.chdir()
     tmpdir.join("setup.cfg").write(dedent("""
     [bumpversion]
@@ -1915,7 +2142,7 @@ def test_regression_dont_touch_capitalization_of_keys_in_config(tmpdir, capsys):
     """).strip() == tmpdir.join("setup.cfg").read().strip()
 
 
-def test_regression_new_version_cli_in_files(tmpdir, capsys):
+def test_regression_new_version_cli_in_files(tmpdir):
     """
     Reported here: https://github.com/peritus/bumpversion/issues/60
     """
@@ -1997,6 +2224,32 @@ def test_retain_newline(tmpdir, configfile, newline):
     assert new_config.endswith(b"[bumpversion:file:file.py]" + newline)
 
 
+def test_no_configured_files(tmpdir, vcs):
+    tmpdir.join("please_ignore_me.txt").write("0.5.5")
+    tmpdir.chdir()
+    tmpdir.join(".bumpversion.cfg").write(dedent("""
+        [bumpversion]
+        current_version = 1.1.1
+        [bumpversion:file:please_ignore_me.txt]
+        """).strip())
+    main(['--no-configured-files', 'patch'])
+    assert "0.5.5" == tmpdir.join("please_ignore_me.txt").read()
+
+
+def test_no_configured_files_still_file_args_work(tmpdir, vcs):
+    tmpdir.join("please_ignore_me.txt").write("0.5.5")
+    tmpdir.join("please_update_me.txt").write("1.1.1")
+    tmpdir.chdir()
+    tmpdir.join(".bumpversion.cfg").write(dedent("""
+        [bumpversion]
+        current_version = 1.1.1
+        [bumpversion:file:please_ignore_me.txt]
+        """).strip())
+    main(['--no-configured-files', 'patch', "please_update_me.txt"])
+    assert "0.5.5" == tmpdir.join("please_ignore_me.txt").read()
+    assert "1.1.2" == tmpdir.join("please_update_me.txt").read()
+
+
 class TestSplitArgsInOptionalAndPositional:
 
     def test_all_optional(self):
